@@ -411,7 +411,7 @@ gchar			*html_escape(const char *val);
 void			set_status(struct tab *t, gchar *fmt, ...);
 
 void			load_webkit_string(struct tab *, const char *, gchar *, int);
-void			button_set_stockid(GtkWidget *, char *);
+void			button_set_icon_name(GtkWidget *, char *);
 void			button_set_file(GtkWidget *, char *);
 void			webview_progress_changed_cb(WebKitWebView *, GParamSpec *, struct tab *);
 
@@ -689,7 +689,6 @@ int		command_mode(struct tab *, struct karg *);
 #define XT_DS_ALLOW_INSECURE_CONTENT	(TRUE)
 #define XT_DS_ALLOW_INSECURE_SCRIPTS	(TRUE)
 #define XT_DS_WARN_CERT_CHANGES	(0)
-#define XT_DS_RESOURCE_DIR	("/usr/local/share/xombrero")
 #define XT_DS_DO_NOT_TRACK	(0)
 #define XT_DS_PRELOAD_STRICT_TRANSPORT	(1)
 #define XT_DS_GNUTLS_PRIORITY_STRING	(NULL)
@@ -805,7 +804,7 @@ struct settings {
 #define XT_S_INVALID	(0)
 #define XT_S_INT	(1)
 #define XT_S_STR	(2)
-#define XT_S_FLOAT	(3)
+#define XT_S_DOUBLE	(3)
 #define XT_S_BOOL	(4)
 	uint32_t	flags;
 #define XT_SF_RESTART	(1<<0)
@@ -814,7 +813,7 @@ struct settings {
 	int		*ival;
 	char		**sval;
 	struct special	*s;
-	double		*fval;
+	double		*dval;
 	int		(*activate)(char *);
 	int		(*ismodified)(char **);
 	char		*tt;
